==> openshift-model-machine-5.10.2-sources.jar: io/fabric8/openshift/api/model/machine/v1beta1/MachineSetSpecBuilder.java <==
package io.fabric8.openshift.api.model.machine.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class MachineSetSpecBuilder extends io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecFluentImpl<io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpec,io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecBuilder>{
  public MachineSetSpecBuilder() {
    this(false);
  }
  public MachineSetSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new MachineSetSpec(), validationEnabled);
  }
  public MachineSetSpecBuilder(io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public MachineSetSpecBuilder(io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new MachineSetSpec(), validationEnabled);
  }
  public MachineSetSpecBuilder(io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecFluent<?> fluent,io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpec instance) {
    this(fluent, instance, false);
  }
  public MachineSetSpecBuilder(io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecFluent<?> fluent,io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDeletePolicy(instance.getDeletePolicy()); 
    fluent.withMinReadySeconds(instance.getMinReadySeconds()); 
    fluent.withReplicas(instance.getReplicas()); 
    fluent.withSelector(instance.getSelector()); 
    fluent.withTemplate(instance.getTemplate()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public MachineSetSpecBuilder(io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpec instance) {
    this(instance,false);
  }
  public MachineSetSpecBuilder(io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withDeletePolicy(instance.getDeletePolicy()); 
    this.withMinReadySeconds(instance.getMinReadySeconds()); 
    this.withReplicas(instance.getReplicas()); 
    this.withSelector(instance.getSelector()); 
    this.withTemplate(instance.getTemplate()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSetSpec build() {
    MachineSetSpec buildable = new MachineSetSpec(fluent.getDeletePolicy(),fluent.getMinReadySeconds(),fluent.getReplicas(),fluent.getSelector(),fluent.getTemplate());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    MachineSetSpecBuilder that = (MachineSetSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-machine-6.4.0-sources.jar: io/fabric8/openshift/api/model/machine/v1beta1/MachineSetSpecBuilder.java <==
package io.fabric8.openshift.api.model.machine.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class MachineSetSpecBuilder extends MachineSetSpecFluentImpl<MachineSetSpecBuilder> implements VisitableBuilder<MachineSetSpec,MachineSetSpecBuilder>{
  public MachineSetSpecBuilder() {
    this(false);
  }
  public MachineSetSpecBuilder(Boolean validationEnabled) {
    this(new MachineSetSpec(), validationEnabled);
  }
  public MachineSetSpecBuilder(MachineSetSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public MachineSetSpecBuilder(MachineSetSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new MachineSetSpec(), validationEnabled);
  }
  public MachineSetSpecBuilder(MachineSetSpecFluent<?> fluent,MachineSetSpec instance) {
    this(fluent, instance, false);
  }
  public MachineSetSpecBuilder(MachineSetSpecFluent<?> fluent,MachineSetSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDeletePolicy(instance.getDeletePolicy()); 
    fluent.withMinReadySeconds(instance.getMinReadySeconds()); 
    fluent.withReplicas(instance.getReplicas()); 
    fluent.withSelector(instance.getSelector()); 
    fluent.withTemplate(instance.getTemplate()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public MachineSetSpecBuilder(MachineSetSpec instance) {
    this(instance,false);
  }
  public MachineSetSpecBuilder(MachineSetSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withDeletePolicy(instance.getDeletePolicy()); 
    this.withMinReadySeconds(instance.getMinReadySeconds()); 
    this.withReplicas(instance.getReplicas()); 
    this.withSelector(instance.getSelector()); 
    this.withTemplate(instance.getTemplate()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  MachineSetSpecFluent<?> fluent;
  Boolean validationEnabled;
  public MachineSetSpec build() {
    MachineSetSpec buildable = new MachineSetSpec(fluent.getDeletePolicy(),fluent.getMinReadySeconds(),fluent.getReplicas(),fluent.getSelector(),fluent.getTemplate());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
